@@ -183,10 +183,12 @@ class SlottedA_length(Base):
         # T=4
         K = 100
         [SAC, slots] = self.slotted_autocorrelation(magnitude, time, self.T, K)
-        SlottedA_length.SAC = SAC
-        SlottedA_length.slots = slots
+        # SlottedA_length.SAC = SAC
+        # SlottedA_length.slots = slots
 
         SAC2 = SAC[slots]
+        SlottedA_length.autocor_vector = SAC2
+
         k = next((index for index, value in
                  enumerate(SAC2) if value < np.exp(-1)), None)
 
@@ -202,8 +204,8 @@ class SlottedA_length(Base):
         return slots[k] * self.T
 
     def getAtt(self):
-        return SlottedA_length.SAC, SlottedA_length.slots
-
+        # return SlottedA_length.SAC, SlottedA_length.slots
+        return SlottedA_length.autocor_vector
 
 class StetsonK_AC(SlottedA_length):
 
@@ -213,9 +215,10 @@ class StetsonK_AC(SlottedA_length):
 
     def fit(self, data):
         a = StetsonK_AC()
-        [autocor_vector, slots] = a.getAtt()
+        # [autocor_vector, slots] = a.getAtt()
+        autocor_vector = a.getAtt()
 
-        autocor_vector = autocor_vector[slots]
+        # autocor_vector = autocor_vector[slots]
         N_autocor = len(autocor_vector)
         sigmap = (np.sqrt(N_autocor * 1.0 / (N_autocor - 1)) *
                  (autocor_vector - np.mean(autocor_vector)) /
